@@ -4,5 +4,7 @@ var (
 	ExportErrEmptyText = errEmptyText
 	// TODO: fixme
 	// ExportErrIncorrectFormat = errIncorrectFormat
-	ExportErrIncorrectFormat = &inputFormatError{}
+	ExportErrIncorrectFormat = func(row string) error {
+		return &inputFormatError{row: row}
+	}
 )
